texinfo-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[no subject]


From: Patrice Dumas
Date: Tue, 8 Nov 2022 03:29:27 -0500 (EST)

branch: master
commit aad7ac7030310f2ccdf72d69dde6fa8ca795fd0a
Author: Patrice Dumas <pertusus@free.fr>
AuthorDate: Thu Nov 3 21:33:09 2022 +0100

    * doc/texi2any_api.texi (Simple Customization for Commands Without
    Arguments), tp/Texinfo/Config.pm
    (texinfo_register_no_arg_command_formatting),
    tp/Texinfo/Convert/HTML.pm (_translate_names): allow to set
    a Texinfo code to be translated and converted as command without
    arguments output.
---
 ChangeLog                                          |   9 +
 doc/texi2any_api.texi                              |  25 ++-
 tp/TODO                                            |   5 -
 tp/Texinfo/Config.pm                               |  22 +-
 tp/Texinfo/Convert/HTML.pm                         |  27 ++-
 tp/init/documentation_examples.pm                  |   6 +
 tp/t/init_files_tests.t                            |  17 +-
 .../init_files_tests/documentation_examples.pl     | 222 +++++++++++++++++++--
 .../res_html/documentation_examples_fot.html       |   8 +-
 .../documentation_examples/res_html/index.html     |  14 +-
 .../res_html/prepended_to_filenames-my-node.html   |  14 +-
 11 files changed, 312 insertions(+), 57 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index 9835759fe6..d9d0562b29 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,12 @@
+2022-11-03  Patrice Dumas  <pertusus@free.fr>
+
+       * doc/texi2any_api.texi (Simple Customization for Commands Without
+       Arguments), tp/Texinfo/Config.pm
+       (texinfo_register_no_arg_command_formatting),
+       tp/Texinfo/Convert/HTML.pm (_translate_names): allow to set
+       a Texinfo code to be translated and converted as command without
+       arguments output.
+
 2022-11-02  Patrice Dumas  <pertusus@free.fr>
 
        * doc/texi2any_api.texi (Simple Navigation Panel Customization):
diff --git a/doc/texi2any_api.texi b/doc/texi2any_api.texi
index 78e0afc8b5..ff9f356d54 100644
--- a/doc/texi2any_api.texi
+++ b/doc/texi2any_api.texi
@@ -466,7 +466,8 @@ To change the formatting of a command, the functions is
 @code{texinfo_register_no_arg_command_formatting}:
 
 @defun texinfo_register_no_arg_command_formatting ($command_name, @
-                  $context, $text, $html_element, $translated_string)
+    $context, $text, $html_element, $translated_string_converted, @
+    $translated_string_to_convert)
 @var{$command_name} is the @@-command name, without the leading @@.
 @var{$context} is @samp{normal}, @samp{preformatted} or @samp{string}.
 There is no separate math context, @samp{preformatted} should be used
@@ -474,12 +475,18 @@ for math context. @xref{Init File Expansion Contexts}.  
If @var{$context}
 is @code{undef}, the @samp{normal} context is assumed.
 
 The remaining arguments determine the formatting.  If @var{$text} is set,
-the corresponding text is output when the @@-command is formatted.  @var{text}
+the corresponding text is output when the @@-command is formatted.  @var{$text}
 can contain HTML elements if needed.  If @var{$html_element} is set, the text
 is enclosed between the @var{$html_element} element opening and the element
-closing.  If @var{$translated_string} is set, @var{$translated_string} is used
-as text and is translated when the document language changes.
-@xref{Texinfo::Translations METHODS,,,texi2any_internals}.
+closing.  If @var{$translated_string_converted} is set, the corresponding
+text is translated when the document language changes and used as text.
+@var{$translated_string_converted} should already be HTML.  If
+@var{$translated_string_to_convert} is set, the corresponding
+text is translated when the document language changes and converted from
+Texinfo code to HTML.  Since the conversion is done in the appropriate
+context, @var{$translated_string_to_convert} should only be set for the
+@samp{normal} context. @xref{Texinfo::Translations
+METHODS,,,texi2any_internals}.
 @end defun
 
 It is not required to set values for all the contexts.  If preformatted context
@@ -510,6 +517,14 @@ texinfo_register_no_arg_command_formatting('error', undef, 
undef, undef,
                                            'error--&gt;');
 @end example
 
+If you want @code{is the @strong{same} as} to be used for @code{@@equiv},
+translated when the document language changes, and converted from Texinfo to
+HTML in the context of the translation, call
+@example
+texinfo_register_no_arg_command_formatting('equiv', undef, undef, undef,
+                                 undef, 'is the @@strong@{same@} as');
+@end example
+
 @xref{Translated Strings Customization} for
 customization of translated strings.
 
diff --git a/tp/TODO b/tp/TODO
index daac355e70..81ea5e4192 100644
--- a/tp/TODO
+++ b/tp/TODO
@@ -42,11 +42,6 @@ Other
 For converter writers,
 'output_init_conf' and 'converter_init_conf'.
 
-'translated_commands' in converters is not documented anywhere nor is there
-a clean way to set it from user code with an API.  Not urgent, as long as
-it is not possible for users to register translated strings and provide with
-translations.
-
 
 Delayed bugs
 ============
diff --git a/tp/Texinfo/Convert/HTML.pm b/tp/Texinfo/Convert/HTML.pm
index 5d55d2665c..66985daca2 100644
--- a/tp/Texinfo/Convert/HTML.pm
+++ b/tp/Texinfo/Convert/HTML.pm
@@ -2144,16 +2144,26 @@ sub _translate_names($)
   my %translated_commands;
   foreach my $context ('normal', 'preformatted', 'string', 'css_string') {
     foreach my $command 
(keys(%{$self->{'no_arg_commands_formatting'}->{$context}})) {
-      if 
(defined($self->{'no_arg_commands_formatting'}->{$context}->{$command}->{'translated'})
-          and not 
$self->{'no_arg_commands_formatting'}->{$context}->{$command}->{'unset'}) {
+      if (defined($self->{'no_arg_commands_formatting'}
+                         ->{$context}->{$command}->{'translated_converted'})
+          and not $self->{'no_arg_commands_formatting'}
+                                        ->{$context}->{$command}->{'unset'}) {
         $translated_commands{$command} = 1;
         $self->{'no_arg_commands_formatting'}->{$context}->{$command}->{'text'}
-         = 
$self->gdt($self->{'no_arg_commands_formatting'}->{$context}->{$command}->{'translated'},
+         = $self->gdt($self->{'no_arg_commands_formatting'}
+                             
->{$context}->{$command}->{'translated_converted'},
                       undef, undef, 'translated_text');
       } elsif ($context eq 'normal') {
-        # default translated commands
-        my $translated_tree = 
Texinfo::Convert::Utils::translated_command_tree($self,
+        my $translated_tree;
+        if (defined($self->{'no_arg_commands_formatting'}
+                      ->{$context}->{$command}->{'translated_to_convert'})) {
+          $translated_tree = $self->gdt($self->{'no_arg_commands_formatting'}
+                          ->{$context}->{$command}->{'translated_to_convert'});
+        } else {
+          # default translated commands
+          $translated_tree = 
Texinfo::Convert::Utils::translated_command_tree($self,
                                                                            
$command);
+        }
         if (defined($translated_tree) and $translated_tree ne '') {
           
$self->{'no_arg_commands_formatting'}->{$context}->{$command}->{'tree'}
             = $translated_tree;
@@ -2169,7 +2179,6 @@ sub _translate_names($)
   print STDERR "END TRANSLATE_NAMES\n\n" if ($self->get_conf('DEBUG'));
 }
 
-
 # redefined functions
 #
 # Texinfo::Translations::gdt redefined to call user defined function.
@@ -2400,7 +2409,7 @@ $default_no_arg_commands_formatting{'normal'}->{"\n"} = 
{'text' => '&nbsp;'};
 # possible example of use, right now not used, as
 # the generic Converter customization is directly used through
 # the call to Texinfo::Convert::Utils::translated_command_tree().
-#$default_no_arg_commands_formatting{'normal'}->{'error'}->{'translated'} = 
'error--&gt;';
+#$default_no_arg_commands_formatting{'normal'}->{'error'}->{'translated_converted'}
 = 'error--&gt;';
 ## This is used to have gettext pick up the chain to be translated
 #if (0) {
 #  my $not_existing;
@@ -6786,7 +6795,7 @@ sub 
_reset_unset_no_arg_commands_formatting_context($$$$;$)
   if (defined($ref_context)) {
     if ($no_arg_command_context->{'unset'}) {
       foreach my $key 
(keys(%{$self->{'no_arg_commands_formatting'}->{$ref_context}->{$cmdname}})) {
-        # both 'translated' and (possibly translated) 'text' are
+        # both 'translated_converted' and (possibly translated) 'text' are
         # reused
         $no_arg_command_context->{$key}
           = 
$self->{'no_arg_commands_formatting'}->{$ref_context}->{$cmdname}->{$key}
@@ -6795,7 +6804,7 @@ sub 
_reset_unset_no_arg_commands_formatting_context($$$$;$)
   }
   if ($translate
       and $no_arg_command_context->{'tree'}
-      and not defined($no_arg_command_context->{'translated'})) {
+      and not defined($no_arg_command_context->{'translated_converted'})) {
     my $translated_tree
       = $no_arg_command_context->{'tree'};
     my $translation_result;
diff --git a/tp/init/documentation_examples.pm 
b/tp/init/documentation_examples.pm
index 2913f508b1..dcd52d4cc3 100644
--- a/tp/init/documentation_examples.pm
+++ b/tp/init/documentation_examples.pm
@@ -35,6 +35,12 @@ texinfo_register_no_arg_command_formatting('-', undef, 
'&shy;');
 texinfo_register_no_arg_command_formatting('error', undef, undef, undef,
                                            'error--&gt;');
 
+texinfo_register_no_arg_command_formatting('equiv', undef, undef, undef,
+                                         undef, 'is the @strong{same} as');
+
+$translations{'fr'}->{'is the @strong{same} as'}->{''}
+                                     = 'est la @strong{m@^eme} que';
+
 texinfo_register_style_command_formatting('sansserif', 'code', 0, 'normal');
 texinfo_register_style_command_formatting('sansserif', 'code', 0, 
'preformatted');
 texinfo_register_style_command_formatting('sansserif', undef, 1, 'string');
diff --git a/tp/t/init_files_tests.t b/tp/t/init_files_tests.t
index 01815cde82..f5c7c21460 100644
--- a/tp/t/init_files_tests.t
+++ b/tp/t/init_files_tests.t
@@ -86,27 +86,36 @@ Text@footnote{In footnote}.
 ', {'init_files' => ['special_element_customization.pm']}],
 ['documentation_examples',
 '
-@settitle @email{someone@@example.com, me} @sansserif{in--title} @error{}
+@settitle @email{someone@@example.com, me} @sansserif{in--title} @error{} 
@equiv{}
 
 @node Top
 
-@sansserif{in--text} @- p--n. @error{}
+@sansserif{in--text} @- p--n. @error{} @equiv{}
 @xref{my node}@footnote{in footnote}.
 @titlefont{in titlefont}
 @email{a@@b.c, someone}
 
-@math{@sansserif{in--math} @- a=b @error{}}
+@math{@sansserif{in--math} @- a=b @error{} @equiv{}}
 
 @example
-@sansserif{in--example} @- c. @error{}
+@sansserif{in--example} @- c. @error{} @equiv{}
 @end example
 
 @documentlanguage fr
 
 @error{}.
 
+@equiv{}
+
 @node my node
 
+@documentlanguage de
+
+@error{}.
+
+@equiv{}
+
+
 ',{'init_files' => ['documentation_examples.pm']},
 ],
 );
diff --git a/tp/t/results/init_files_tests/documentation_examples.pl 
b/tp/t/results/init_files_tests/documentation_examples.pl
index 029b771561..0f2426aedf 100644
--- a/tp/t/results/init_files_tests/documentation_examples.pl
+++ b/tp/t/results/init_files_tests/documentation_examples.pl
@@ -89,6 +89,22 @@ $result_trees{'documentation_examples'} = {
                     'line_nr' => 2,
                     'macro' => ''
                   }
+                },
+                {
+                  'text' => ' '
+                },
+                {
+                  'args' => [
+                    {
+                      'type' => 'brace_command_arg'
+                    }
+                  ],
+                  'cmdname' => 'equiv',
+                  'source_info' => {
+                    'file_name' => '',
+                    'line_nr' => 2,
+                    'macro' => ''
+                  }
                 }
               ],
               'extra' => {
@@ -180,6 +196,22 @@ $result_trees{'documentation_examples'} = {
                 'macro' => ''
               }
             },
+            {
+              'text' => ' '
+            },
+            {
+              'args' => [
+                {
+                  'type' => 'brace_command_arg'
+                }
+              ],
+              'cmdname' => 'equiv',
+              'source_info' => {
+                'file_name' => '',
+                'line_nr' => 6,
+                'macro' => ''
+              }
+            },
             {
               'text' => '
 '
@@ -216,6 +248,96 @@ $result_trees{'documentation_examples'} = {
                   'contents' => [
                     {
                       'text' => '
+',
+                      'type' => 'empty_line'
+                    },
+                    {
+                      'args' => [
+                        {
+                          'contents' => [
+                            {
+                              'text' => 'de'
+                            }
+                          ],
+                          'extra' => {
+                            'spaces_after_argument' => '
+'
+                          },
+                          'type' => 'line_arg'
+                        }
+                      ],
+                      'cmdname' => 'documentlanguage',
+                      'extra' => {
+                        'spaces_before_argument' => ' ',
+                        'text_arg' => 'de'
+                      },
+                      'source_info' => {
+                        'file_name' => '',
+                        'line_nr' => 25,
+                        'macro' => ''
+                      }
+                    },
+                    {
+                      'text' => '
+',
+                      'type' => 'empty_line'
+                    },
+                    {
+                      'contents' => [
+                        {
+                          'args' => [
+                            {
+                              'type' => 'brace_command_arg'
+                            }
+                          ],
+                          'cmdname' => 'error',
+                          'source_info' => {
+                            'file_name' => '',
+                            'line_nr' => 27,
+                            'macro' => ''
+                          }
+                        },
+                        {
+                          'text' => '.
+'
+                        }
+                      ],
+                      'type' => 'paragraph'
+                    },
+                    {
+                      'text' => '
+',
+                      'type' => 'empty_line'
+                    },
+                    {
+                      'contents' => [
+                        {
+                          'args' => [
+                            {
+                              'type' => 'brace_command_arg'
+                            }
+                          ],
+                          'cmdname' => 'equiv',
+                          'source_info' => {
+                            'file_name' => '',
+                            'line_nr' => 29,
+                            'macro' => ''
+                          }
+                        },
+                        {
+                          'text' => '
+'
+                        }
+                      ],
+                      'type' => 'paragraph'
+                    },
+                    {
+                      'text' => '
+',
+                      'type' => 'empty_line'
+                    },
+                    {
+                      'text' => '
 ',
                       'type' => 'empty_line'
                     }
@@ -237,7 +359,7 @@ $result_trees{'documentation_examples'} = {
                   },
                   'source_info' => {
                     'file_name' => '',
-                    'line_nr' => 21,
+                    'line_nr' => 23,
                     'macro' => ''
                   }
                 },
@@ -400,6 +522,22 @@ $result_trees{'documentation_examples'} = {
                         'line_nr' => 11,
                         'macro' => ''
                       }
+                    },
+                    {
+                      'text' => ' '
+                    },
+                    {
+                      'args' => [
+                        {
+                          'type' => 'brace_command_arg'
+                        }
+                      ],
+                      'cmdname' => 'equiv',
+                      'source_info' => {
+                        'file_name' => '',
+                        'line_nr' => 11,
+                        'macro' => ''
+                      }
                     }
                   ],
                   'type' => 'brace_command_context'
@@ -478,6 +616,22 @@ $result_trees{'documentation_examples'} = {
                     'macro' => ''
                   }
                 },
+                {
+                  'text' => ' '
+                },
+                {
+                  'args' => [
+                    {
+                      'type' => 'brace_command_arg'
+                    }
+                  ],
+                  'cmdname' => 'equiv',
+                  'source_info' => {
+                    'file_name' => '',
+                    'line_nr' => 14,
+                    'macro' => ''
+                  }
+                },
                 {
                   'text' => '
 '
@@ -578,6 +732,33 @@ $result_trees{'documentation_examples'} = {
         },
         {
           'text' => '
+',
+          'type' => 'empty_line'
+        },
+        {
+          'contents' => [
+            {
+              'args' => [
+                {
+                  'type' => 'brace_command_arg'
+                }
+              ],
+              'cmdname' => 'equiv',
+              'source_info' => {
+                'file_name' => '',
+                'line_nr' => 21,
+                'macro' => ''
+              }
+            },
+            {
+              'text' => '
+'
+            }
+          ],
+          'type' => 'paragraph'
+        },
+        {
+          'text' => '
 ',
           'type' => 'empty_line'
         }
@@ -607,53 +788,70 @@ $result_trees{'documentation_examples'} = {
   ],
   'type' => 'document_root'
 };
-$result_trees{'documentation_examples'}{'contents'}[1]{'contents'}[1]{'contents'}[6]{'extra'}{'label'}{'extra'}{'node_content'}[0]
 = 
$result_trees{'documentation_examples'}{'contents'}[1]{'contents'}[1]{'contents'}[6]{'extra'}{'label'}{'args'}[0]{'contents'}[0];
-$result_trees{'documentation_examples'}{'contents'}[1]{'contents'}[1]{'contents'}[6]{'extra'}{'label'}{'extra'}{'nodes_manuals'}[0]{'node_content'}[0]
 = 
$result_trees{'documentation_examples'}{'contents'}[1]{'contents'}[1]{'contents'}[6]{'extra'}{'label'}{'args'}[0]{'contents'}[0];
-$result_trees{'documentation_examples'}{'contents'}[1]{'contents'}[1]{'contents'}[6]{'extra'}{'node_argument'}{'node_content'}[0]
 = 
$result_trees{'documentation_examples'}{'contents'}[1]{'contents'}[1]{'contents'}[6]{'args'}[0]{'contents'}[0];
+$result_trees{'documentation_examples'}{'contents'}[1]{'contents'}[1]{'contents'}[8]{'extra'}{'label'}{'extra'}{'node_content'}[0]
 = 
$result_trees{'documentation_examples'}{'contents'}[1]{'contents'}[1]{'contents'}[8]{'extra'}{'label'}{'args'}[0]{'contents'}[0];
+$result_trees{'documentation_examples'}{'contents'}[1]{'contents'}[1]{'contents'}[8]{'extra'}{'label'}{'extra'}{'nodes_manuals'}[0]{'node_content'}[0]
 = 
$result_trees{'documentation_examples'}{'contents'}[1]{'contents'}[1]{'contents'}[8]{'extra'}{'label'}{'args'}[0]{'contents'}[0];
+$result_trees{'documentation_examples'}{'contents'}[1]{'contents'}[1]{'contents'}[8]{'extra'}{'node_argument'}{'node_content'}[0]
 = 
$result_trees{'documentation_examples'}{'contents'}[1]{'contents'}[1]{'contents'}[8]{'args'}[0]{'contents'}[0];
 
$result_trees{'documentation_examples'}{'contents'}[1]{'extra'}{'node_content'}[0]
 = 
$result_trees{'documentation_examples'}{'contents'}[1]{'args'}[0]{'contents'}[0];
 
$result_trees{'documentation_examples'}{'contents'}[1]{'extra'}{'nodes_manuals'}[0]{'node_content'}[0]
 = 
$result_trees{'documentation_examples'}{'contents'}[1]{'args'}[0]{'contents'}[0];
-$result_trees{'documentation_examples'}{'contents'}[2] = 
$result_trees{'documentation_examples'}{'contents'}[1]{'contents'}[1]{'contents'}[6]{'extra'}{'label'};
+$result_trees{'documentation_examples'}{'contents'}[2] = 
$result_trees{'documentation_examples'}{'contents'}[1]{'contents'}[1]{'contents'}[8]{'extra'}{'label'};
 
 $result_texis{'documentation_examples'} = '
-@settitle @email{someone@@example.com, me} @sansserif{in--title} @error{}
+@settitle @email{someone@@example.com, me} @sansserif{in--title} @error{} 
@equiv{}
 
 @node Top
 
-@sansserif{in--text} @- p--n. @error{}
+@sansserif{in--text} @- p--n. @error{} @equiv{}
 @xref{my node}@footnote{in footnote}.
 @titlefont{in titlefont}
 @email{a@@b.c, someone}
 
-@math{@sansserif{in--math} @- a=b @error{}}
+@math{@sansserif{in--math} @- a=b @error{} @equiv{}}
 
 @example
-@sansserif{in--example} @- c. @error{}
+@sansserif{in--example} @- c. @error{} @equiv{}
 @end example
 
 @documentlanguage fr
 
 @error{}.
 
+@equiv{}
+
 @node my node
 
+@documentlanguage de
+
+@error{}.
+
+@equiv{}
+
+
 ';
 
 
 $result_texts{'documentation_examples'} = '
 
 
-in-text  p-n. error-->
+in-text  p-n. error--> ==
 my node.
 in titlefont
 someone
 
-in--math  a=b error-->
+in--math  a=b error--> ==
+
+in--example  c. error--> ==
+
+
+error-->.
+
+==
 
-in--example  c. error-->
 
 
 error-->.
 
+==
+
 
 ';
 
diff --git 
a/tp/t/results/init_files_tests/documentation_examples/res_html/documentation_examples_fot.html
 
b/tp/t/results/init_files_tests/documentation_examples/res_html/documentation_examples_fot.html
index 6c74fe1ab2..6d2d635211 100644
--- 
a/tp/t/results/init_files_tests/documentation_examples/res_html/documentation_examples_fot.html
+++ 
b/tp/t/results/init_files_tests/documentation_examples/res_html/documentation_examples_fot.html
@@ -3,10 +3,10 @@
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
-<title>Notes de bas de page (someone@example.com (me) undefined 
text-align:center, is undef|end|separate in&ndash;title erreur--&gt;)</title>
+<title>Fußnoten (someone@example.com (me) undefined text-align:center, is 
undef|end|separate in&ndash;title Fehler--&gt; is the same as)</title>
 
-<meta name="description" content="Notes de bas de page (someone@example.com 
(me) undefined text-align:center, is undef|end|separate in&ndash;title 
erreur--&gt;)">
-<meta name="keywords" content="Notes de bas de page (someone@example.com (me) 
undefined text-align:center, is undef|end|separate in&ndash;title 
erreur--&gt;)">
+<meta name="description" content="Fußnoten (someone@example.com (me) undefined 
text-align:center, is undef|end|separate in&ndash;title Fehler--&gt; is the 
same as)">
+<meta name="keywords" content="Fußnoten (someone@example.com (me) undefined 
text-align:center, is undef|end|separate in&ndash;title Fehler--&gt; is the 
same as)">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
 <meta name="viewport" content="width=device-width,initial-scale=1">
@@ -23,7 +23,7 @@
  &nbsp; </p>
 </div>
 <hr>
-<h4 class="footnotes-heading">Notes de bas de page</h4>
+<h4 class="footnotes-heading">Fußnoten</h4>
 
 <h5 class="footnote-body-heading"><a id="FOOT1" 
href="index.html#DOCF1">(1)</a></h5>
 <p>in footnote <code>HTML</code> text </p>
diff --git 
a/tp/t/results/init_files_tests/documentation_examples/res_html/index.html 
b/tp/t/results/init_files_tests/documentation_examples/res_html/index.html
index 3e0102a096..cd712e8ceb 100644
--- a/tp/t/results/init_files_tests/documentation_examples/res_html/index.html
+++ b/tp/t/results/init_files_tests/documentation_examples/res_html/index.html
@@ -3,10 +3,10 @@
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
-<title>Top (someone@example.com (me) undefined text-align:center, is 
undef|end|separate in&ndash;title erreur--&gt;)</title>
+<title>Top (someone@example.com (me) undefined text-align:center, is 
undef|end|separate in&ndash;title erreur--&gt; est la m&ecirc;me que)</title>
 
-<meta name="description" content="Top (someone@example.com (me) undefined 
text-align:center, is undef|end|separate in&ndash;title erreur--&gt;)">
-<meta name="keywords" content="Top (someone@example.com (me) undefined 
text-align:center, is undef|end|separate in&ndash;title erreur--&gt;)">
+<meta name="description" content="Top (someone@example.com (me) undefined 
text-align:center, is undef|end|separate in&ndash;title erreur--&gt; est la 
m&ecirc;me que)">
+<meta name="keywords" content="Top (someone@example.com (me) undefined 
text-align:center, is undef|end|separate in&ndash;title erreur--&gt; est la 
m&ecirc;me que)">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
 <meta name="viewport" content="width=device-width,initial-scale=1">
@@ -33,20 +33,22 @@ Suivant: <a href="prepended_to_filenames-my-node.html" 
accesskey="n" rel="next">
 <hr>
 <h1 class="node">Top</h1>
 
-<p><code class="sansserif">in--text</code> &shy; p--n. error--&gt;
+<p><code class="sansserif">in--text</code> &shy; p--n. error--&gt; is the 
<strong class="strong">same</strong> as
 See <a class="xref" href="prepended_to_filenames-my-node.html">my node</a><a 
class="footnote" id="DOCF1_2" 
href="documentation_examples_fot.html#FOOT1_2"><sup>2</sup></a>.
  <code>HTML</code> text </p><h1 class="titlefont">in titlefont</h1>
 <p><a class="email" href="mailto:a@b.c";>someone</a> [undefined 
text-align:center, is undef|end|separate]
  <code>HTML</code> text </p>
-<p><em class="math"><code class="sansserif">in--math</code> &shy; a=b 
error--&gt;</em>
+<p><em class="math"><code class="sansserif">in--math</code> &shy; a=b 
error--&gt; is the <strong class="strong">same</strong> as</em>
  <code>HTML</code> text </p>
 <div class="example">
-<pre class="example-preformatted"><code class="sansserif">in--example</code> 
&shy; c. error--&gt;
+<pre class="example-preformatted"><code class="sansserif">in--example</code> 
&shy; c. error--&gt; is the <strong class="strong">same</strong> as
 </pre></div>
 
 
 <p>erreur--&gt;.
  <code>HTML</code> text </p>
+<p>est la <strong class="strong">m&ecirc;me</strong> que
+ <code>HTML</code> text </p>
 <hr>
 <div class="nav-panel">
 <p>
diff --git a/tp/Texinfo/Config.pm b/tp/Texinfo/Config.pm
index 623f3224a5..1acedd33e4 100644
--- a/tp/Texinfo/Config.pm
+++ b/tp/Texinfo/Config.pm
@@ -542,20 +542,18 @@ sub _GNUT_initialize_special_element_info()
 
 _GNUT_initialize_special_element_info();
 
 # $translated_string is supposed to be already formatted.
 # It may also be relevant to be able to pass a 'tree'
 # directly (it is actually handled by the converter code).
-# Passing a texinfo string that can be translated (like
-# the 'translated_commands' customization variable) may also
-# be interesting.
-sub texinfo_register_no_arg_command_formatting($$;$$$)
+sub texinfo_register_no_arg_command_formatting($$;$$$$)
 {
   my $command = shift;
   my $context = shift;
   my $text = shift;
   # html element
   my $element = shift;
-  my $translated_string = shift;
+  my $translated_converted_string = shift;
+  my $translated_to_convert_string = shift;
 
   if (!defined($context)) {
     $context = $default_formatting_context;
@@ -571,10 +569,18 @@ sub texinfo_register_no_arg_command_formatting($$;$$$)
   if (defined($element)) {
     $specification->{'element'} = $element;
   }
-  if (defined($translated_string)) {
-    $specification->{'translated'} = $translated_string;
+  if (defined($translated_converted_string)) {
+    $specification->{'translated_converted'} = $translated_converted_string;
     # NOTE unset 'text'?  A priori not needed, it will be overwritten
   }
+  if (defined($translated_to_convert_string)) {
+    # only need to register in normal context, as the Texinfo code
+    # will be converted in the appropriate context.
+    if ($context ne $default_formatting_context) {
+      return 0;
+    }
+    $specification->{'translated_to_convert'} = $translated_to_convert_string;
+  }
   $GNUT_no_arg_commands_formatting_strings->{$context}->{$command} = 
$specification;
   return 1;
@@ -542,20 +542,18 @@ sub _GNUT_initialize_special_element_info()
 _GNUT_initialize_special_element_info();
 
-# $translated_string is supposed to be already formatted.
+# $translated_converted_string is supposed to be already formatted.
 # It may also be relevant to be able to pass a 'tree'
 # directly (it is actually handled by the converter code).
 }
diff --git 
a/tp/t/results/init_files_tests/documentation_examples/res_html/prepended_to_filenames-my-node.html
 
b/tp/t/results/init_files_tests/documentation_examples/res_html/prepended_to_filenames-my-node.html
index 375a4d1014..b6d686ee5e 100644
--- 
a/tp/t/results/init_files_tests/documentation_examples/res_html/prepended_to_filenames-my-node.html
+++ 
b/tp/t/results/init_files_tests/documentation_examples/res_html/prepended_to_filenames-my-node.html
@@ -3,10 +3,10 @@
 <!-- Created by texinfo, http://www.gnu.org/software/texinfo/ -->
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
-<title>my node (someone@example.com (me) undefined text-align:center, is 
undef|end|separate in&ndash;title erreur--&gt;)</title>
+<title>my node (someone@example.com (me) undefined text-align:center, is 
undef|end|separate in&ndash;title Fehler--&gt; is the same as)</title>
 
-<meta name="description" content="my node (someone@example.com (me) undefined 
text-align:center, is undef|end|separate in&ndash;title erreur--&gt;)">
-<meta name="keywords" content="my node (someone@example.com (me) undefined 
text-align:center, is undef|end|separate in&ndash;title erreur--&gt;)">
+<meta name="description" content="my node (someone@example.com (me) undefined 
text-align:center, is undef|end|separate in&ndash;title Fehler--&gt; is the 
same as)">
+<meta name="keywords" content="my node (someone@example.com (me) undefined 
text-align:center, is undef|end|separate in&ndash;title Fehler--&gt; is the 
same as)">
 <meta name="resource-type" content="document">
 <meta name="distribution" content="global">
 <meta name="viewport" content="width=device-width,initial-scale=1">
@@ -20,12 +20,18 @@
 <body lang="en">
 <a class="node-id" id="prepended_to_labels-my-node"></a><div class="nav-panel">
 <p>
-Pr&eacute;c&eacute;dent: <a href="index.html" accesskey="p" rel="prev">Top</a> 
&nbsp; </p>
+Vorige: <a href="index.html" accesskey="p" rel="prev">Top</a> &nbsp; </p>
 </div>
 <hr>
 <h4 class="node">my node</h4>
 
 
+<p>Fehler--&gt;.
+ <code>HTML</code> text </p>
+<p>is the <strong class="strong">same</strong> as
+ <code>HTML</code> text </p>
+
+
 
 
 </body>



reply via email to

[Prev in Thread] Current Thread [Next in Thread]